# Changelog

## [1.5.0](https://github.com/microsoft/kiota-python/compare/microsoft-kiota-bundle-v1.4.6...microsoft-kiota-bundle-v1.5.0) (2024-10-22)


### Features

* Add bundle package for python. ([e53d0f7](https://github.com/microsoft/kiota-python/commit/e53d0f7da3950d625628538e3a1e152044100e43))
* Add bundle package for python. ([93efa4d](https://github.com/microsoft/kiota-python/commit/93efa4d440aa78330949ba1f335734ef87d0c4e5))


### Bug Fixes

* adds missing version 12 for bundle ([7989272](https://github.com/microsoft/kiota-python/commit/798927274d2cfdb0142e5a4457a682bf706cd8ba))
* typo ([7e607e7](https://github.com/microsoft/kiota-python/commit/7e607e769aa9c9da43416b200231f7d879b8794c))

## Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).
